;; Generated package description from agitate.el  -*- no-byte-compile: t -*-
(define-package "agitate" "0.0.20221020.43414" "Extras for diff-mode, vc-git, log-edit, log-view" '((emacs "28.1")) :commit "ca771320e71729250600055bc0a301009dbe8571" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Agitate Development" . "~protesilaos/agitate@lists.sr.ht") :keywords '("convenience" "version control" "git") :url "https://git.sr.ht/~protesilaos/agitate")
